#ifndef CREATEALLKNOTS_H_
#define CREATEALLKNOTS_H_


ClutterActor *create_knot_with_pos(ClutterActor *stage, gint pos_x, gint pos_y);
ClutterActor *create_points_with_pos(ClutterActor *stage, gint pos_x, gint pos_y);
void create_all_knots(ClutterActor *parent, ClutterActor **matrix, GCallback on_spot_enter, GCallback verify_path);
void make_reactive_all_knots(ClutterActor **matrix,	gint size, gboolean make_reactive);

#endif /* CREATEALLKNOTS_H_ */



